==> ci-hotel_V1.0.0_20101217.zip: ci-hotel_1.0.0_20101217/system/application/views/res/userinp.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
?>
<style type="text/css">
@import "<?php echo base_url() ?>/js/jquery.timeentry.package-1.4.8/jquery.timeentry.css";
</style>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery/jquery-1.4.2.js"></script>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/jquery.timeentry.js"></script>
<script type="text/javascript">
$(function () {
	$('#time1').timeEntry({show24Hours: true, timeSteps: [0, 30, 0], defaultTime: '18:00', spinnerImage: '<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/spinnerDefault.png'});
});
</script>

<?php
include(dirname(__FILE__) . '/../header2.php');
?>
<image src="<?php echo site_url('images/step3.png') ?>">

<h2>お客様情報入力</h2>

<?php echo form_open('res/userinp/'); ?>

<table class="inp">
<tr><th width="200px">* 氏名 :</th><td>
<input type="text" name="name" value="<?php echo set_value('name', isset($name) ? $name : ''); ?>" size="40" />
<?php echo form_error('name'); ?>
</td></tr>
<tr><th>* 氏名(かな) :</th><td>
<input type="text" name="name_kana" value="<?php echo set_value('name_kana', isset($name_kana) ? $name_kana : ''); ?>" size="40" />
<?php echo form_error('name_kana'); ?>
</td></tr>
<tr><th>* メールアドレス :</th><td>
<input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="40" />
<?php echo form_error('email'); ?>
</td></tr>
<tr><th>* 郵便番号 :</th><td>
<input type="text" name="postcode" value="<?php echo set_value('postcode', isset($postcode) ? $postcode : ''); ?>" size="10" />
<?php echo form_error('postcode'); ?>
</td></tr>
<tr><th>* 都道府県 :</th><td>
<?php
$prefecture_options = array(
    '' => '--', '北海道' => '北海道',
    '青森県' => '青森県', '岩手県' => '岩手県', '宮城県' => '宮城県', '秋田県' => '秋田県',
    '山形県' => '山形県', '福島県' => '福島県', '茨城県' => '茨城県', '栃木県' => '栃木県',
    '群馬県' => '群馬県', '埼玉県' => '埼玉県', '千葉県' => '千葉県', '東京都' => '東京都',
    '神奈川県' => '神奈川県', '新潟県' => '新潟県', '富山県' => '富山県', '石川県' => '石川県',
    '福井県' => '福井県', '山梨県' => '山梨県', '長野県' => '長野県', '岐阜県' => '岐阜県',
    '静岡県' => '静岡県', '愛知県' => '愛知県', '三重県' => '三重県', '滋賀県' => '滋賀県',
    '京都府' => '京都府', '大阪府' => '大阪府', '兵庫県' => '兵庫県', '奈良県' => '奈良県',
    '和歌山県' => '和歌山県', '鳥取県' => '鳥取県', '島根県' => '島根県', '岡山県' => '岡山県',
    '広島県' => '広島県', '山口県' => '山口県', '徳島県' => '徳島県', '香川県' => '香川県',
    '愛媛県' => '愛媛県', '高知県' => '高知県', '福岡県' => '福岡県', '佐賀県' => '佐賀県',
    '長崎県' => '長崎県', '熊本県' => '熊本県', '大分県' => '大分県', '宮崎県' => '宮崎県',
    '鹿児島県' => '鹿児島県', '沖縄県' => '沖縄県'
);
echo form_dropdown('prefecture', $prefecture_options, set_value('prefecture', isset($prefecture) ? $prefecture : ''));
echo form_error('prefecture');
?>
</td></tr>
<tr><th>* 市区町村 :</th><td>
<input type="text" name="city" value="<?php echo set_value('city', isset($city) ? $city : ''); ?>" size="40" />
<?php echo form_error('city'); ?>
</td></tr>
<tr><th>* 番地 :</th><td>
<input type="text" name="street" value="<?php echo set_value('street', isset($street) ? $street : ''); ?>" size="40" />
<?php echo form_error('street'); ?>
</td></tr>
<tr><th>* 電話番号 :</th><td>
<input type="text" name="phone" value="<?php echo set_value('phone', isset($phone) ? $phone : ''); ?>" size="20" />
<?php echo form_error('phone'); ?>
</td></tr>
<tr><th>チェックイン時刻 :</th><td>
<input type="text" name="cinhour" id="time1" value="<?php echo set_value('cinhour', isset($cinhour) ? $cinhour : ''); ?>" size="20" />
<?php echo form_error('cinhour'); ?>
</td></tr>
<tr><th>備考欄 :</th><td>
<textarea name="memo" rows="3" cols="40">
<?php echo set_value('memo', isset($memo) ? $memo : ''); ?>
</textarea>
<?php echo form_error('memo'); ?>
</td></tr>
</table>

<input type="submit" name="submit" value="確認画面に進む" />
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>

==> ci-hotel_V1.2.0_20110206.zip: ci-hotel_1.2.0_20110206/system/application/views/res/userinp.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
?>
<style type="text/css">
@import "<?php echo base_url() ?>/js/jquery.timeentry.package-1.4.8/jquery.timeentry.css";
</style>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery/jquery-1.4.2.js"></script>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/jquery.timeentry.js"></script>
<script type="text/javascript">
$(function () {
	$('#time1').timeEntry({show24Hours: true, timeSteps: [0, 30, 0], defaultTime: '18:00', spinnerImage: '<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/spinnerDefault.png'});
});
</script>

<?php
include(dirname(__FILE__) . '/../header2.php');
?>
<image src="<?php echo site_url('images/step3.png') ?>">

<h2>お客様情報入力</h2>

<?php echo form_open('res/userinp/' . $hotelid); ?>

<table class="inp">
<tr><th width="200px">* 氏名 :</th><td>
<input type="text" name="name" value="<?php echo set_value('name', isset($name) ? $name : ''); ?>" size="40" />
<?php echo form_error('name'); ?>
</td></tr>
<tr><th>* 氏名(かな) :</th><td>
<input type="text" name="name_kana" value="<?php echo set_value('name_kana', isset($name_kana) ? $name_kana : ''); ?>" size="40" />
<?php echo form_error('name_kana'); ?>
</td></tr>
<tr><th>* メールアドレス :</th><td>
<input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="40" />
<?php echo form_error('email'); ?>
</td></tr>
<tr><th>* 郵便番号 :</th><td>
<input type="text" name="postcode" value="<?php echo set_value('postcode', isset($postcode) ? $postcode : ''); ?>" size="10" />
<?php echo form_error('postcode'); ?>
</td></tr>
<tr><th>* 都道府県 :</th><td>
<?php
$prefecture_options = array(
    '' => '--', '北海道' => '北海道',
    '青森県' => '青森県', '岩手県' => '岩手県', '宮城県' => '宮城県', '秋田県' => '秋田県',
    '山形県' => '山形県', '福島県' => '福島県', '茨城県' => '茨城県', '栃木県' => '栃木県',
    '群馬県' => '群馬県', '埼玉県' => '埼玉県', '千葉県' => '千葉県', '東京都' => '東京都',
    '神奈川県' => '神奈川県', '新潟県' => '新潟県', '富山県' => '富山県', '石川県' => '石川県',
    '福井県' => '福井県', '山梨県' => '山梨県', '長野県' => '長野県', '岐阜県' => '岐阜県',
    '静岡県' => '静岡県', '愛知県' => '愛知県', '三重県' => '三重県', '滋賀県' => '滋賀県',
    '京都府' => '京都府', '大阪府' => '大阪府', '兵庫県' => '兵庫県', '奈良県' => '奈良県',
    '和歌山県' => '和歌山県', '鳥取県' => '鳥取県', '島根県' => '島根県', '岡山県' => '岡山県',
    '広島県' => '広島県', '山口県' => '山口県', '徳島県' => '徳島県', '香川県' => '香川県',
    '愛媛県' => '愛媛県', '高知県' => '高知県', '福岡県' => '福岡県', '佐賀県' => '佐賀県',
    '長崎県' => '長崎県', '熊本県' => '熊本県', '大分県' => '大分県', '宮崎県' => '宮崎県',
    '鹿児島県' => '鹿児島県', '沖縄県' => '沖縄県'
);
echo form_dropdown('prefecture', $prefecture_options, set_value('prefecture', isset($prefecture) ? $prefecture : ''));
echo form_error('prefecture');
?>
</td></tr>
<tr><th>* 市区町村 :</th><td>
<input type="text" name="city" value="<?php echo set_value('city', isset($city) ? $city : ''); ?>" size="40" />
<?php echo form_error('city'); ?>
</td></tr>
<tr><th>* 番地 :</th><td>
<input type="text" name="street" value="<?php echo set_value('street', isset($street) ? $street : ''); ?>" size="40" />
<?php echo form_error('street'); ?>
</td></tr>
<tr><th>* 電話番号 :</th><td>
<input type="text" name="phone" value="<?php echo set_value('phone', isset($phone) ? $phone : ''); ?>" size="20" />
<?php echo form_error('phone'); ?>
</td></tr>
<tr><th>チェックイン時刻 :</th><td>
<input type="text" name="cinhour" id="time1" value="<?php echo set_value('cinhour', isset($cinhour) ? $cinhour : ''); ?>" size="20" />
<?php echo form_error('cinhour'); ?>
</td></tr>
<tr><th>備考欄 :</th><td>
<textarea name="memo" rows="3" cols="40">
<?php echo set_value('memo', isset($memo) ? $memo : ''); ?>
</textarea>
<?php echo form_error('memo'); ?>
</td></tr>
</table>

<input type="submit" name="submit" value="確認画面に進む" />
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>
